# <span style="color: #89CFF0;">x</span>nano

> _extremely nano_ tools for building llm workflows; **made for regular people**.

<br/>

`xnano` stems from my frustration with the 'complexity' and boilerplate of most llm libraries. It aims to provide incredibly rich features & functionality through single functions and minimal modules.

## Install with `pip`

```bash
pip install xnano
```

<br/>
